
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.32'
version = '1.2.32'
full_version = '1.2.32'
git_revision = 'e0901c0ea4a274448eac2b40c7111c28ddda3df9'
release = True

if not release:
    version = full_version
    short_version += ".dev"
